@@ -3,12 +3,12 @@ require "spec_helper"
 module Capistrano
   class Configuration
     describe Question do
-      let(:question) { Question.new(key, default, options) }
-      let(:question_without_echo) { Question.new(key, default, echo: false) }
-      let(:question_without_default) { Question.new(key, nil) }
+      let(:question) { Question.new(key, default, stdin: stdin) }
+      let(:question_without_echo) { Question.new(key, default, echo: false, stdin: stdin) }
+      let(:question_without_default) { Question.new(key, nil, stdin: stdin) }
       let(:default) { :default }
       let(:key) { :branch }
-      let(:options) { nil }
+      let(:stdin) { stub(tty?: true) }
 
       describe ".new" do
         it "takes a key, default, options" do
@@ -22,15 +22,15 @@ module Capistrano
 
           it "returns the echoed value" do
             $stdout.expects(:print).with("Please enter branch (default): ")
-            $stdin.expects(:gets).returns(branch)
-            $stdin.expects(:noecho).never
+            stdin.expects(:gets).returns(branch)
+            stdin.expects(:noecho).never
 
             expect(question.call).to eq(branch)
           end
 
           it "returns the value but does not echo it" do
             $stdout.expects(:print).with("Please enter branch (default): ")
-            $stdin.expects(:noecho).returns(branch)
+            stdin.expects(:noecho).returns(branch)
             $stdout.expects(:print).with("\n")
 
             expect(question_without_echo.call).to eq(branch)
@@ -38,8 +38,8 @@ module Capistrano
 
           it "returns the value but has no default between parenthesis" do
             $stdout.expects(:print).with("Please enter branch: ")
-            $stdin.expects(:gets).returns(branch)
-            $stdin.expects(:noecho).never
+            stdin.expects(:gets).returns(branch)
+            stdin.expects(:noecho).never
 
             expect(question_without_default.call).to eq(branch)
           end
@@ -50,7 +50,7 @@ module Capistrano
 
           before do
             $stdout.expects(:print).with("Please enter branch (default): ")
-            $stdin.expects(:gets).returns("")
+            stdin.expects(:gets).returns("")
           end
 
           it "returns the default as the value" do
@@ -58,10 +58,10 @@ module Capistrano
           end
         end
 
-        context "tty unavailable" do
+        context "tty unavailable", capture_io: true do
           before do
-            $stdin.expects(:gets).never
-            $stdin.expects(:tty?).returns(false)
+            stdin.expects(:gets).never
+            stdin.expects(:tty?).returns(false)
           end
 
           it "returns the default as the value" do
